<template>
  <el-dialog v-dialogDrag
             :title="dialog.title"
             :visible.sync="dialog.showDialog"
             width="1200px"
             :append-to-body="true"
             class="avue-dialog"
             :destroy-on-close="true"
             :close-on-click-modal="false"
             @close="cancelDialog">
    <el-container style="height: 580px">
      <el-aside style="width: 380px">
        <basic-container style="height: 530px">
          <h3 style="margin: 0 0 10px 0">业务类型</h3>
          <div style="height: 435px">
            <avue-tree ref="tree" :data="treeData" :option="treeOption" @node-click="nodeClick">
              <span slot-scope="{ node, data }" class="el-tree-node__label">
               <span style="font-size: 15px">
                    {{ (node || {}).label }}
                </span>
              </span>
            </avue-tree>
          </div>
        </basic-container>
      </el-aside>

      <el-main>
        <basic-container style="height: 530px">
          <div style="height: 520px;">
            <avue-tree ref="uiTree" :data="uiTreeData" :option="uiTreeOption">
              <span slot-scope="{ node, data }" class="el-tree-node__label">
                <span style="font-size: 15px">
                  <i :class="data.icon"></i>
                    {{ (node || {}).label }}
                </span>
              </span>
            </avue-tree>
          </div>
        </basic-container>
      </el-main>
    </el-container>
    <div class="dialog-footer avue-dialog__footer">
      <el-button type="primary" plain size="small" @click="submitDialog" >保 存</el-button>
      <el-button size="small" @click="cancelDialog">取 消</el-button>
    </div>
  </el-dialog>
</template>

<script>
import {getUIAuthor} from "@/api/authority/ui/uiAuthor";
import {getBizTree} from "@/api/UI/uiDefine";

export default {
name: "cloneDialog",
  data(){
    return {
      dialog: {
        showDialog: false,
        title: "克隆目标",
        loading: false,
        type: "clone",
      },
      treeOption: {
        menu: false,
        addBtn: false,
        props: {
          label: 'text',
          value: 'oid',
          children: 'children'
        }
      },
      nodeRow: {},
      treeData: [],
      defaultExpandKeys:[],
      uiTreeOption: {
        nodeKey:'oid',
        checkOnClickNode:true,
        defaultExpandedKeys:this.defaultExpandKeys,
        multiple: true,
        menu: false,
        addBtn: false,
        filter:false,
        props: {
          label: 'label',
          value: 'oid',
          children: 'children'
        }
      },
      uiTreeData: [],
    };
  },
  methods: {
    openDialog( data) {
      this.dialog.showDialog = true;
      this.getTreeList()
      this.uiTreeData=[];
    },
    cancelDialog() {
      this.dialog.loading = false;
      this.dialog.showDialog = false;
    },
    submitDialog() {
      linkSave({}).then(res => {
        if (res.data.success) {
          this.$message.success("克隆成功");
          this.cancelDialog();
          this.$emit("refresh");
        }
      });
    },
    getTreeList() {
      const loading = this.$loading({});
      getBizTree().then(res => {
        this.treeData =res.data.obj.children;
        loading.close();
      }).catch(error=>{
        loading.close();
      })
    },
    // 角色点击
    nodeClick(row,node) {
      this.nodeRow = row;
      const loading = this.$loading({});
      const params = {
        'conditionMap[roleId]': this.nodeRow.oid,
        'conditionMap[type]': this.type,
        'conditionMap[context]': this.context
      }
      this.defaultExpandKeys=['root'];
      getUIAuthor(params).then(res => {
        this.processChildren(res.data.data[0]); // 处理每个节点
        this.uiTreeOption.defaultExpandedKeys=this.defaultExpandKeys;
        this.uiTreeData = [{
          attributes: {},
          checked: false,
          expanded: true,
          data: "root",
          level: 0,
          icon: 'el-icon-s-home',
          oid: res.data.data[0].oid,
          label: 'UI上下文选项',
          children: res.data.data[0].children
        }];
        loading.close();
      }).catch(error => {
        loading.close();
      })
    },
    //处理树
    processChildren(item) {
      if (item.children && item.children.length > 0) {
        item.children = item.children.map(child => {
          if(child.level<4){
            this.defaultExpandKeys.push(child.oid)
          }
          if(child.level==1){
            child.icon='el-icon-s-promotion';
            child.label=child.data.label+'('+child.data.name+')'
          }else if(child.level==2){
            child.icon='el-icon-s-order';
            child.label=child.text
          }else if(child.level==3){
            child.icon='el-icon-office-building';
            child.label=child.text
          }else if(child.level==4){
            child.icon='el-icon-document';
            child.label=child.text
          }else if(child.level==5){
            child.icon='el-icon-s-tools';
            child.label=child.text
          }
          this.processChildren(child); // 递归处理每个子节点
          return child; // 只返回子节点的 attributes
        });
      }
    },
  },
}
</script>

<style scoped>

</style>
